import prisma from '#utilities/prisma'
import { Chat } from '@prisma/client'

class ChatRepository {
  async getById(id: number): Promise<Chat | null> {
    return prisma.chat.findUnique({
      where: { id },
      include: {
        character: true,
        zone: true
      }
    })
  }

  async getAll(): Promise<Chat[]> {
    return prisma.chat.findMany({
      include: {
        character: true,
        zone: true
      }
    })
  }

  async getByCharacterId(characterId: number): Promise<Chat[]> {
    return prisma.chat.findMany({
      where: {
        characterId
      },
      include: {
        character: true,
        zone: true
      }
    })
  }

  async getByZoneId(zoneId: number): Promise<Chat[]> {
    return prisma.chat.findMany({
      where: {
        zoneId
      },
      include: {
        character: true,
        zone: true
      }
    })
  }
}

export default new ChatRepository()
